import Color from "./Color";
/**
 * 駒を表すクラス
 */
export default class Piece {
    /**
     * 成った時の種類を返す．なければそのまま．
     */
    static promote(kind: string): string;
    /**
     * 表に返した時の種類を返す．表の場合はそのまま．
     */
    static unpromote(kind: string): string;
    /**
     * 成れる駒かどうかを返す
     */
    static canPromote(kind: string): boolean;
    static isPromoted(kind: string): boolean;
    static oppositeColor(color: Color): Color;
    /**
     * SFENによる文字列表現から駒オブジェクトを作成
     */
    static fromSFENString(sfen: string): Piece;
    /**
     * 先後
     */
    color: Color;
    /**
     * 駒の種類
     */
    kind: string;
    /**
     * "+FU"などのCSAによる駒表現から駒オブジェクトを作成
     */
    constructor(csa: string);
    /**
     * 成る
     */
    promote(): void;
    /**
     * 不成にする
     */
    unpromote(): void;
    /**
     * 駒の向きを反転する
     */
    inverse(): void;
    /**
     * CSAによる駒表現の文字列を返す
     */
    toCSAString(): string;
    /**
     * SFENによる駒表現の文字列を返す
     */
    toSFENString(): string;
}
